Imagedata Documentation — imagedata 1.4.3dev0 documentation

# Imagedata Documentation

Imagedata is a python library to read and write medical image data into numpy arrays. Imagedata will handle multi-dimensional data. In particular, imagedata will read and sort DICOM 3D and 4D series based on defined tags. Imagedata will handle geometry information between the formats.

Imagedata initially supports the following formats:

- DICOM

- Nifti

- ITK (MetaIO)

- Matlab

- PostScript (input only)

Other formats can be added through a plugin architecture.

A simple example reading a time series from in_dir, displaying it, and writing it to out_dir:

    from imagedata.series import Series
    a = Series('in_dir', 'time')
    a.show()
    a.write('out_dir')

The User Guide explains how to install and use imagedata.

Loading image data with this imagedata Python package simplify image processing pipelines both in native Python, and when stitching together modules that require different image file formats. This is especially important when setting up pipelines for clinical data where patient information matters.

Contents:

- User Guide
  - Installation
  - Tutorial
  - Motivation and goals
  - Design
  - Series Class
  - Input/output
  - Sorting
  - DICOM Attributes
  - Console Applications
  - Examples
  - Plugin Architecture
  - ReleaseNotes
  - API Reference
- Developer Documentation
  - Writing plugins
  - Generating distribution archives
  - Uploading the distribution archives
  - Installing your newly uploaded package
  - Build the documentation
  - Version numbers
  - Uploading official release

# Indices and tables

- Index

- Module Index

- Search Page